@@ -6,9 +6,11 @@ group = "org.gradle.sample"
 version = "1.0"
 
 publishing {
-    // tag::customize-descriptor[]
+// tag::customize-descriptor[]
+// tag::versions-resolved[]
     publications {
         create<IvyPublication>("ivyCustom") {
+            // end::versions-resolved[]
             descriptor {
                 license {
                     name.set("The Apache License, Version 2.0")
@@ -23,8 +25,18 @@ publishing {
                     homepage.set("http://www.example.com/library")
                 }
             }
+// tag::versions-resolved[]
+            versionMapping {
+                usage("java-api") {
+                    fromResolutionOf("runtimeClasspath")
+                }
+                usage("java-runtime") {
+                    fromResolutionResult()
+                }
+            }
         }
     }
+// end::versions-resolved[]
 // end::customize-descriptor[]
     repositories {
         ivy {
