@@ -8,7 +8,7 @@ subprojects {
     }
 
     dependencies {
-        "testCompile"("junit:junit:4.12")
+        "testImplementation"("junit:junit:4.12")
     }
 
 // tag::test-report[]
